@@ -28,8 +28,6 @@ from oslo_log import log
 from oslo_serialization import jsonutils
 from oslo_utils import timeutils
 
-from manila.i18n import _LE
-
 scheduler_json_config_location_opt = cfg.StrOpt(
     'scheduler_json_config_location',
     default='',
@@ -64,19 +62,18 @@ class SchedulerOptions(object):
         """Get the last modified datetime. Broken out for testing."""
         try:
             return os.path.getmtime(filename)
-        except os.error as e:
-            LOG.exception(_LE("Could not stat scheduler options file "
-                              "%(filename)s: '%(e)s'"),
-                          {"filename": filename, "e": e})
+        except os.error:
+            LOG.exception("Could not stat scheduler options file "
+                          "%(filename)s.",
+                          {"filename": filename})
             raise
 
     def _load_file(self, handle):
         """Decode the JSON file. Broken out for testing."""
         try:
             return jsonutils.load(handle)
-        except ValueError as e:
-            LOG.exception(_LE("Could not decode scheduler options: "
-                              "'%(e)s'"), {"e": e})
+        except ValueError:
+            LOG.exception("Could not decode scheduler options.")
             return {}
 
     def _get_time_now(self):
